@@ -12,34 +12,35 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 /*
  * Items of instruction view.
  */
 
-#include <qpixmap.h>
-#include <qpainter.h>
+#include "instritem.h"
+
+#include <QPixmap>
+#include <QPainter>
+#include <QPolygon>
 
 #include <klocale.h>
-#include <kapplication.h>
 #include <kiconloader.h>
 #include <kdebug.h>
 
 #include "configuration.h"
 #include "listutils.h"
-#include "instritem.h"
 #include "instrview.h"
 
 
 // InstrItem
 
 // for messages
-InstrItem::InstrItem(InstrView* iv, QListView* parent,
+InstrItem::InstrItem(InstrView* iv, Q3ListView* parent,
 		     Addr addr, const QString& msg)
-    : QListViewItem(parent)
+    : Q3ListViewItem(parent)
 {
   _view = iv;
   _addr = addr;
@@ -47,20 +48,20 @@ InstrItem::InstrItem(InstrView* iv, QListView* parent,
   _instrCall = 0;
   _instrJump = 0;
   _inside = false;
-  
+
   setText(0, addr.pretty());
   setText(6, msg);
-  
+
   updateGroup();
   updateCost();
 }
 
 // for code lines
-InstrItem::InstrItem(InstrView* iv, QListView* parent,
+InstrItem::InstrItem(InstrView* iv, Q3ListView* parent,
 		     Addr addr, bool inside,
 		     const QString& code, const QString& cmd,
 		     const QString& args, TraceInstr* instr)
-    : QListViewItem(parent)
+    : Q3ListViewItem(parent)
 {
   _view = iv;
   _addr = addr;
@@ -86,9 +87,9 @@ InstrItem::InstrItem(InstrView* iv, QListView* parent,
 }
 
 // for call lines
-InstrItem::InstrItem(InstrView* iv, QListViewItem* parent, Addr addr,
+InstrItem::InstrItem(InstrView* iv, Q3ListViewItem* parent, Addr addr,
 		     TraceInstr* instr, TraceInstrCall* instrCall)
-    : QListViewItem(parent)
+    : Q3ListViewItem(parent)
 {
   _view = iv;
   _addr = addr;
@@ -101,13 +102,14 @@ InstrItem::InstrItem(InstrView* iv, QListViewItem* parent, Addr addr,
   //       fileno, lineno, _lineCall->call()->called()->prettyName().ascii());
 
   SubCost cc = _instrCall->callCount();
-  QString templ = "  ";
+  QString callStr = "  ";
   if (cc==0)
-    templ += i18n("Active call to '%1'");
+    callStr += i18n("Active call to '%1'",
+                    _instrCall->call()->calledName());
   else
-    templ += i18n("%n call to '%1'", "%n calls to '%1'", cc);
+    callStr += i18np("%1 call to '%2'", "%1 calls to '%2'", (uint64)cc,
+                     _instrCall->call()->calledName());
 
-  QString callStr = templ.arg(_instrCall->call()->calledName());
   TraceFunction* calledF = _instrCall->call()->called();
   calledF->addPrettyLocation(callStr);
 
@@ -118,9 +120,9 @@ InstrItem::InstrItem(InstrView* iv, QListViewItem* parent, Addr addr,
 }
 
 // for jump lines
-InstrItem::InstrItem(InstrView* iv, QListViewItem* parent, Addr addr,
+InstrItem::InstrItem(InstrView* iv, Q3ListViewItem* parent, Addr addr,
 		     TraceInstr* instr, TraceInstrJump* instrJump)
-    : QListViewItem(parent)
+    : Q3ListViewItem(parent)
 {
   _view = iv;
   _addr = addr;
@@ -134,14 +136,14 @@ InstrItem::InstrItem(InstrView* iv, QListViewItem* parent, Addr addr,
 
   QString jStr;
   if (_instrJump->isCondJump())
-      jStr = i18n("Jump %1 of %2 times to 0x%3")
-	  .arg(_instrJump->followedCount().pretty())
-	  .arg(_instrJump->executedCount().pretty())
-	  .arg(_instrJump->instrTo()->addr().toString());
+      jStr = i18n("Jump %1 of %2 times to 0x%3",
+	   _instrJump->followedCount().pretty(),
+	   _instrJump->executedCount().pretty(),
+	   _instrJump->instrTo()->addr().toString());
   else
-      jStr = i18n("Jump %1 times to 0x%2")
-	  .arg(_instrJump->executedCount().pretty())
-	  .arg(_instrJump->instrTo()->addr().toString());
+      jStr = i18n("Jump %1 times to 0x%2",
+	   _instrJump->executedCount().pretty(),
+	   _instrJump->instrTo()->addr().toString());
 
   setText(6, jStr);
 
@@ -170,17 +172,17 @@ void InstrItem::updateCost()
   TraceCost* instrCost = _instrCall ?
       (TraceCost*)_instrCall : (TraceCost*)_instr;
 
-  // don't show any cost inside of cycles
+  // do not show any cost inside of cycles
   if (_instrCall &&
       ((_instrCall->call()->inCycle()>0) ||
-       (_instrCall->call()->isRecursion()>0))) {
+       (_instrCall->call()->isRecursion()))) {
     QString str;
     QPixmap p;
 
-    QString icon = "undo";
-    KIconLoader* loader = KApplication::kApplication()->iconLoader();
-    p= loader->loadIcon(icon, KIcon::Small, 0,
-                        KIcon::DefaultState, 0, true);
+    QString icon = "edit-undo";
+    KIconLoader* loader = KIconLoader::global();
+    p= loader->loadIcon(icon, KIconLoader::Small, 0,
+                        KIconLoader::DefaultState, QStringList(), 0, true);
     if (p.isNull())
       str = i18n("(cycle)");
 
@@ -197,10 +199,10 @@ void InstrItem::updateCost()
   else
       totalCost = _instr->function()->data();
 
-  TraceCostType *ct = _view->costType();
+  TraceEventType *ct = _view->eventType();
   _pure = ct ? instrCost->subCost(ct) : SubCost(0);
   if (_pure == 0) {
-    setText(1, QString::null);
+    setText(1, QString());
     setPixmap(1, QPixmap());
   }
   else {
@@ -212,14 +214,14 @@ void InstrItem::updateCost()
 	      .arg(pure, 0, 'f', Configuration::percentPrecision()));
     else
       setText(1, _pure.pretty());
-    
+
     setPixmap(1, costPixmap(ct, instrCost, total, false));
   }
 
-  TraceCostType *ct2 = _view->costType2();
+  TraceEventType *ct2 = _view->eventType2();
   _pure2 = ct2 ? instrCost->subCost(ct2) : SubCost(0);
   if (_pure2 == 0) {
-    setText(2, QString::null);
+    setText(2, QString());
     setPixmap(2, QPixmap());
   }
   else {
@@ -231,13 +233,13 @@ void InstrItem::updateCost()
 	      .arg(pure, 0, 'f', Configuration::percentPrecision()));
     else
       setText(2, _pure2.pretty());
-    
+
     setPixmap(2, costPixmap(ct2, instrCost, total, false));
   }
 }
 
 
-int InstrItem::compare(QListViewItem * i, int col, bool ascending ) const
+int InstrItem::compare(Q3ListViewItem * i, int col, bool ascending ) const
 {
   const InstrItem* ii1 = this;
   const InstrItem* ii2 = (InstrItem*) i;
@@ -293,7 +295,7 @@ int InstrItem::compare(QListViewItem * i, int col, bool ascending ) const
     return 0;
 
   }
-  return QListViewItem::compare(i, col, ascending);
+  return Q3ListViewItem::compare(i, col, ascending);
 }
 
 void InstrItem::paintCell( QPainter *p, const QColorGroup &cg,
@@ -301,38 +303,40 @@ void InstrItem::paintCell( QPainter *p, const QColorGroup &cg,
 {
   QColorGroup _cg( cg );
 
-  if ( !_inside || ((column==1) || column==2))
-    _cg.setColor( QColorGroup::Base, cg.button() );
+  QColor color;
+  if ( !_inside || ((column==1) || (column==2)))
+    color = cg.color( QPalette::Button );
   else if ((_instrCall || _instrJump) && column>2)
-    _cg.setColor( QColorGroup::Base, cg.midlight() );
+    color = cg.color( QPalette::Midlight );
+  if (color.isValid())
+    _cg.setColor( listView()->viewport()->backgroundRole(), color);
 
   if (column == 3)
     paintArrows(p, _cg, width);
   else
-    QListViewItem::paintCell( p, _cg, column, width, alignment );
+    Q3ListViewItem::paintCell( p, _cg, column, width, alignment );
 }
 
-void InstrItem::setJumpArray(const QMemArray<TraceInstrJump*>& a)
+void InstrItem::setJumpArray(const QVector<TraceInstrJump*>& a)
 {
-    _jump.duplicate(a);
+    _jump = a;
 }
 
 void InstrItem::paintArrows(QPainter *p, const QColorGroup &cg, int width)
 {
-  QListView *lv = listView();
+  Q3ListView *lv = listView();
   if ( !lv ) return;
   InstrView* iv = (InstrView*) lv;
 
-  const BackgroundMode bgmode = lv->viewport()->backgroundMode();
-  const QColorGroup::ColorRole crole
-    = QPalette::backgroundRoleFromMode( bgmode );
-  if ( cg.brush( crole ) != lv->colorGroup().brush( crole ) )
-    p->fillRect( 0, 0, width, height(), cg.brush( crole ) );
+  QPalette pal = cg;
+  const QPalette::ColorRole crole = lv->viewport()->backgroundRole();
+  if (pal.brush(crole) != lv->palette().brush(crole))
+    p->fillRect(0, 0, width, height(), pal.brush(crole));
   else
     iv->paintEmptyArea( p, QRect( 0, 0, width, height() ) );
 
   if ( isSelected() && lv->allColumnsShowFocus() )
-    p->fillRect( 0, 0, width, height(), cg.brush( QColorGroup::Highlight ) );
+    p->fillRect( 0, 0, width, height(), cg.brush( QPalette::Highlight ) );
 
   int marg = lv->itemMargin();
   int yy = height()/2, y1, y2;
@@ -349,7 +353,7 @@ void InstrItem::paintArrows(QPainter *p, const QColorGroup &cg, int width)
       if ((_instrJump == _jump[i]) &&
 	  (_jump[i]->instrFrom()->addr() == _addr)) {
 
-	  //kdDebug() << "InstrItem " << _addr.toString() << ": start " << i << endl;
+	  //kDebug() << "InstrItem " << _addr.toString() << ": start " << i;
 	  if (start<0) start = i;
 	  if (_jump[i]->instrTo()->addr() <= _addr)
 	      y2 = yy;
@@ -359,7 +363,7 @@ void InstrItem::paintArrows(QPainter *p, const QColorGroup &cg, int width)
       else if (!_instrJump && !_instrCall &&
 	       (_jump[i]->instrTo()->addr() == _addr)) {
 
-	  //kdDebug() << "InstrItem " << _addr.toString() << ": end " << i << endl;
+	  //kDebug() << "InstrItem " << _addr.toString() << ": end " << i;
 	  if (end<0) end = i;
 	  if (_jump[i]->instrFrom()->addr() < _addr)
 	      y2 = yy;
@@ -367,12 +371,12 @@ void InstrItem::paintArrows(QPainter *p, const QColorGroup &cg, int width)
 	      y1 = yy;
       }
 
-      c = _jump[i]->isCondJump() ? red : blue;
+      c = _jump[i]->isCondJump() ? Qt::red : Qt::blue;
 #if 0
-      if (_jump[i] == ((TraceItemView*)_view)->selectedItem()) {	  
+      if (_jump[i] == ((TraceItemView*)_view)->selectedItem()) {
 	  p->fillRect( marg + 6*i-2, (y1==0) ? y1: y1-2,
 		       8, (y2-y1==height())? y2:y2+2,
-		       cg.brush( QColorGroup::Highlight ) );
+		       cg.brush( QPalette::Highlight ) );
 	  c = lv->colorGroup().highlightedText();
       }
 #endif
@@ -387,11 +391,11 @@ void InstrItem::paintArrows(QPainter *p, const QColorGroup &cg, int width)
   int x, y = yy-2, w, h = 4;
   if (start >= 0) {
 #if 0
-      if (_jump[start] == ((TraceItemView*)_view)->selectedItem()) {	  
+      if (_jump[start] == ((TraceItemView*)_view)->selectedItem()) {
 	  c = lv->colorGroup().highlightedText();
       }
 #endif
-      c = _jump[start]->isCondJump() ? red : blue;
+      c = _jump[start]->isCondJump() ? Qt::red : Qt::blue;
       x = marg + 6*start;
       w = 6*(iv->arrowLevels() - start) + 10;
       p->fillRect( x, y, w, h, c);
@@ -403,26 +407,27 @@ void InstrItem::paintArrows(QPainter *p, const QColorGroup &cg, int width)
       p->drawLine(x+1, y+h-1, x+w-1, y+h-1);
   }
   if (end >= 0) {
-      c = _jump[end]->isCondJump() ? red : blue;
+      c = _jump[end]->isCondJump() ? Qt::red : Qt::blue;
       x = marg + 6*end;
       w = 6*(iv->arrowLevels() - end) + 10;
 
-      QPointArray a;
-      a.putPoints(0, 7, x, y+h,
-		  x,y, x+w-8, y, x+w-8, y-2,
-		  x+w, yy,
-		  x+w-8, y+h+2, x+w-8, y+h);
+      QPolygon a;
+      a.putPoints(0, 8, x,y+h,
+		  x,y, x+w-8,y, x+w-8,y-2,
+		  x+w,yy,
+		  x+w-8,y+h+2, x+w-8,y+h,
+		  x,y+h);
       p->setBrush(c);
       p->drawConvexPolygon(a);
 
       p->setPen(c.light());
-      p->drawPolyline(a, 0, 5);
+      p->drawPolyline(a.constData(), 5);
       p->setPen(c.dark());
-      p->drawPolyline(a, 4, 2);
+      p->drawPolyline(a.constData() + 4, 2);
       p->setPen(c.light());
-      p->drawPolyline(a, 5, 2);
+      p->drawPolyline(a.constData() + 5, 2);
       p->setPen(c.dark());
-      p->drawPolyline(a, 6, 2);
+      p->drawPolyline(a.constData() + 6, 2);
   }
 
   // draw inner vertical line for start/stop
@@ -430,12 +435,12 @@ void InstrItem::paintArrows(QPainter *p, const QColorGroup &cg, int width)
   for(int i=0;i< (int)_jump.size();i++) {
       if (_jump[i] == 0) continue;
 
-      c = _jump[i]->isCondJump() ? red : blue;
+      c = _jump[i]->isCondJump() ? Qt::red : Qt::blue;
 
       if (_jump[i]->instrFrom()->addr() == _addr) {
 	  bool drawUp = true;
 	  if (_jump[i]->instrTo()->addr() == _addr)
-	      if (start<0) drawUp=false;	  
+	      if (start<0) drawUp=false;
 	  if (_jump[i]->instrTo()->addr() > _addr) drawUp=false;
 	  if (drawUp)
 	      p->fillRect( marg + 6*i +1, 0, 2, yy, c);
@@ -454,9 +459,9 @@ void InstrItem::paintArrows(QPainter *p, const QColorGroup &cg, int width)
 }
 
 int InstrItem::width( const QFontMetrics& fm,
-                      const QListView* lv, int c ) const
+                      const Q3ListView* lv, int c ) const
 {
-  if (c != 3) return QListViewItem::width(fm, lv, c);
+  if (c != 3) return Q3ListViewItem::width(fm, lv, c);
 
   InstrView* iv = (InstrView*) lv;
   int levels = iv->arrowLevels();
