@@ -1,13 +1,11 @@
 /***************************************************************************
-                                kompare_part.cpp  -  description
-                                -------------------
+                                kompare_part.cpp
+                                ----------------
         begin                   : Sun Mar 4 2001
-        copyright               : (C) 2001-2004 Otto Bruggeman
-                                  (C) 2001-2003 John Firebaugh
-                                  (C) 2004      Jeff Snyder
-        email                   : otto.bruggeman@home.nl
-                                  jfirebaugh@kde.org
-                                  jeff@caffeinated.me.uk
+        Copyright 2001-2005,2009 Otto Bruggeman <bruggie@gmail.com>
+        Copyright 2001-2003 John Firebaugh <jfirebaugh@kde.org>
+        Copyright 2004      Jeff Snyder    <jeff@caffeinated.me.uk>
+        Copyright 2007-2009 Kevin Kofler   <kevin.kofler@chello.at>
 ****************************************************************************/
 
 /***************************************************************************
@@ -19,25 +17,28 @@
 **
 ***************************************************************************/
 
-#include "kompare_qsplitter.h" // make sure we get there first
+#include "kompare_part.h"
 
-#include <qlayout.h>
-#include <qwidget.h>
+#include <QtGui/QLayout>
+#include <QtGui/QWidget>
 
 #include <kaction.h>
+#include <kactioncollection.h>
 #include <kapplication.h>
 #include <kdebug.h>
-#include <kfiletreeview.h>
 #include <kfiledialog.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <kstdaction.h>
-#include <kinstance.h>
-#include <ktempfile.h>
+#include <kstandardaction.h>
+#include <kstandarddirs.h>
+#include <kstandardshortcut.h>
+#include <kcomponentdata.h>
+#include <ktemporaryfile.h>
 #include <kparts/genericfactory.h>
-//#include <ktempdir.h>
+#include <ktempdir.h>
 
 #include <kio/netaccess.h>
+#include <kglobal.h>
 
 #include "diffmodel.h"
 #include "komparelistview.h"
@@ -48,22 +49,19 @@
 #include "komparesaveoptionswidget.h"
 #include "komparesplitter.h"
 
-#include "kompare_part.h"
-
 typedef KParts::GenericFactory<KomparePart> KomparePartFactory;
 K_EXPORT_COMPONENT_FACTORY( libkomparepart, KomparePartFactory )
 
 ViewSettings* KomparePart::m_viewSettings = 0L;
 DiffSettings* KomparePart::m_diffSettings = 0L;
 
-KomparePart::KomparePart( QWidget *parentWidget, const char *widgetName,
-                      QObject *parent, const char *name, const QStringList & /*args*/ ) :
-	KParts::ReadWritePart(parent, name),
+KomparePart::KomparePart( QWidget *parentWidget, QObject *parent, const QStringList & /*args*/ ) :
+	KParts::ReadWritePart(parent),
 	m_tempDiff( 0 ),
 	m_info()
 {
 	// we need an instance
-	setInstance( KomparePartFactory::instance() );
+	setComponentData( KomparePartFactory::componentData() );
 
 	if( !m_viewSettings ) {
 		m_viewSettings = new ViewSettings( 0 );
@@ -72,10 +70,19 @@ KomparePart::KomparePart( QWidget *parentWidget, const char *widgetName,
 		m_diffSettings = new DiffSettings( 0 );
 	}
 
-	readProperties( kapp->config() );
+	readProperties( KGlobal::config().data() );
+
+	m_splitter = new KompareSplitter ( m_viewSettings, parentWidget );
+
+	// !!! Do not change this ->parentWidget()! Due to the bizarre reparenting hacks in KompareSplitter, !!!
+	// !!! the ->parentWidget() is not the one passed in the constructor, but the scroll view created    !!!
+	// !!! within the KompareSplitter. If you use m_splitter here, the scroll bars will not be shown!    !!!
+	// !!! Using the parentWidget parameter is also wrong, of course, you have to use m_splitter->...!   !!!
+	setWidget( m_splitter->parentWidget() );
 
 	// This creates the "Model creator" and connects the signals and slots
-	m_modelList = new Diff2::KompareModelList( m_diffSettings, m_info, this, "komparemodellist" );
+	m_modelList = new Diff2::KompareModelList( m_diffSettings, m_splitter, this, "komparemodellist" );
+
 	connect( m_modelList, SIGNAL(status( Kompare::Status )),
 	         this, SLOT(slotSetStatus( Kompare::Status )) );
 	connect( m_modelList, SIGNAL(setStatusBarModelInfo( int, int, int, int, int )),
@@ -90,9 +97,7 @@ KomparePart::KomparePart( QWidget *parentWidget, const char *widgetName,
 	         this, SIGNAL(appliedChanged()) );
 	connect( m_modelList, SIGNAL(applyDifference( bool )),
 	         this, SIGNAL(appliedChanged()) );
-
-	connect( m_modelList, SIGNAL( setModified( bool ) ),
-	         this, SLOT( slotSetModified( bool ) ) );
+	connect( m_modelList, SIGNAL(updateActions()), this, SLOT(updateActions()) );
 
 	// This is the stuff to connect the "interface" of the kompare part to the model inside
 	connect( m_modelList, SIGNAL(modelsChanged(const Diff2::DiffModelList*)),
@@ -114,10 +119,12 @@ KomparePart::KomparePart( QWidget *parentWidget, const char *widgetName,
 	         this, SIGNAL(applyAllDifferences(bool)) );
 	connect( m_modelList, SIGNAL(applyDifference(const Diff2::Difference*, bool)),
 	         this, SIGNAL(applyDifference(const Diff2::Difference*, bool)) );
+	connect( m_modelList, SIGNAL(diffString(const QString&)),
+	         this, SIGNAL(diffString(const QString&)) );
 
-	// This creates the splitterwidget and connects the signals and slots
-	m_splitter = new KompareSplitter ( m_viewSettings, parentWidget, widgetName );
+	connect( this, SIGNAL(kompareInfo(Kompare::Info*)), m_modelList, SLOT(slotKompareInfo(Kompare::Info*)) );
 
+	// Here we connect the splitter to the modellist
 	connect( m_modelList, SIGNAL(setSelection(const Diff2::DiffModel*, const Diff2::Difference*)),
 	         m_splitter,  SLOT(slotSetSelection(const Diff2::DiffModel*, const Diff2::Difference*)) );
 //	connect( m_splitter,  SIGNAL(selectionChanged(const Diff2::Difference*, const Diff2::Difference*)),
@@ -135,9 +142,6 @@ KomparePart::KomparePart( QWidget *parentWidget, const char *widgetName,
 	         m_splitter, SLOT(slotApplyDifference(const Diff2::Difference*, bool)) );
 	connect( this, SIGNAL(configChanged()), m_splitter, SIGNAL(configChanged()) );
 
-	// notify the part that this is our internal widget
-	setWidget( m_splitter->parentWidget() );
-
 	setupActions();
 
 	// set our XML-UI resource file
@@ -162,49 +166,52 @@ void KomparePart::setupActions()
 {
 	// create our actions
 
-	m_saveAll         = new KAction( i18n("Save &All"), "save_all", 0,
-	                                 this, SLOT(saveAll()),
-	                                 actionCollection(), "file_save_all" );
-	m_saveDiff        = new KAction( i18n("Save .&diff..."), 0,
-	                                 this, SLOT(saveDiff()),
-	                                 actionCollection(), "file_save_diff" );
-	m_swap            = new KAction( i18n( "Swap Source with Destination" ), 0,
-	                                 this, SLOT(slotSwap()),
-	                                 actionCollection(), "file_swap" );
-	m_diffStats       = new KAction( i18n( "Show Statistics" ), 0,
-	                                 this, SLOT(slotShowDiffstats()),
-	                                 actionCollection(), "file_diffstats" );
+	m_saveAll = actionCollection()->addAction("file_save_all", this, SLOT(saveAll()));
+	m_saveAll->setIcon(KIcon("document-save-all"));
+	m_saveAll->setText(i18n("Save &All"));
+	m_saveDiff = actionCollection()->addAction("file_save_diff", this, SLOT(saveDiff()));
+	m_saveDiff->setText(i18n("Save .&diff..."));
+	m_swap = actionCollection()->addAction("file_swap", this, SLOT(slotSwap()));
+	m_swap->setText(i18n("Swap Source with Destination"));
+	m_diffStats = actionCollection()->addAction("file_diffstats", this, SLOT(slotShowDiffstats()));
+	m_diffStats->setText(i18n("Show Statistics"));
+	m_diffRefresh = actionCollection()->addAction("file_refreshdiff", this, SLOT(slotRefreshDiff()));
+	m_diffRefresh->setIcon(KIcon("view-refresh"));
+	m_diffRefresh->setText(i18n("Refresh Diff"));
+	m_diffRefresh->setShortcut(KStandardShortcut::reload());
 
-	KStdAction::preferences(this, SLOT(optionsPreferences()), actionCollection());
+	KStandardAction::preferences(this, SLOT(optionsPreferences()), actionCollection());
 }
 
 void KomparePart::updateActions()
 {
-	m_saveAll->setEnabled  ( m_modelList->isModified() );
+	m_saveAll->setEnabled     ( m_modelList->hasUnsavedChanges() );
 	m_saveDiff->setEnabled ( m_modelList->mode() == Kompare::ComparingFiles || m_modelList->mode() == Kompare::ComparingDirs );
 	m_swap->setEnabled     ( m_modelList->mode() == Kompare::ComparingFiles || m_modelList->mode() == Kompare::ComparingDirs );
+	m_diffRefresh->setEnabled( m_modelList->mode() == Kompare::ComparingFiles || m_modelList->mode() == Kompare::ComparingDirs );
 	m_diffStats->setEnabled( m_modelList->modelCount() > 0 );
 }
 
 void KomparePart::setEncoding( const QString& encoding )
 {
-	kdDebug() << "Encoding: " << encoding << endl;
+	kDebug(8103) << "Encoding: " << encoding << endl;
 	m_modelList->setEncoding( encoding );
 }
 
-bool KomparePart::openDiff( const KURL& url )
+bool KomparePart::openDiff( const KUrl& url )
 {
-	kdDebug(8103) << "Url = " << url.url() << endl;
-
-	emit kompareInfo( &m_info );
+	kDebug(8103) << "Url = " << url.url() << endl;
 
 	m_info.mode = Kompare::ShowingDiff;
 	m_info.source = url;
 	bool result = false;
-	m_info.localSource = fetchURL( url );
+	fetchURL( url, true );
+
+	emit kompareInfo( &m_info );
+
 	if ( !m_info.localSource.isEmpty() )
 	{
-		kdDebug(8103) << "Download succeeded " << endl;
+		kDebug(8103) << "Download succeeded " << endl;
 		result = m_modelList->openDiff( m_info.localSource );
 		updateActions();
 		updateCaption();
@@ -212,7 +219,7 @@ bool KomparePart::openDiff( const KURL& url )
 	}
 	else
 	{
-		kdDebug(8103) << "Download failed !" << endl;
+		kDebug(8103) << "Download failed !" << endl;
 	}
 
 	return result;
@@ -222,10 +229,10 @@ bool KomparePart::openDiff( const QString& diffOutput )
 {
 	bool value = false;
 
-	emit kompareInfo( &m_info );
-
 	m_info.mode = Kompare::ShowingDiff;
 
+	emit kompareInfo( &m_info );
+
 	if ( m_modelList->parseDiffOutput( diffOutput ) == 0 )
 	{
 		value = true;
@@ -238,18 +245,18 @@ bool KomparePart::openDiff( const QString& diffOutput )
 	return value;
 }
 
-bool KomparePart::openDiff3( const KURL& diff3Url )
+bool KomparePart::openDiff3( const KUrl& diff3Url )
 {
 	// FIXME: Implement this !!!
-	kdDebug(8103) << "Not implemented yet. Filename is: " << diff3Url.url() << endl;
+	kDebug(8103) << "Not implemented yet. Filename is: " << diff3Url.prettyUrl() << endl;
 	return false;
 }
 
 bool KomparePart::openDiff3( const QString& diff3Output )
 {
 	// FIXME: Implement this !!!
-	kdDebug(8103) << "Not implemented yet. diff3 output is: " << endl;
-	kdDebug(8103) << diff3Output << endl;
+	kDebug(8103) << "Not implemented yet. diff3 output is: " << endl;
+	kDebug(8103) << diff3Output << endl;
 	return false;
 }
 
@@ -259,102 +266,187 @@ bool KomparePart::exists( const QString& url )
 	return fi.exists();
 }
 
-const QString KomparePart::fetchURL( const KURL& url )
+bool KomparePart::fetchURL( const KUrl& url, bool addToSource )
 {
+	// Default value if there is an error is "", we rely on it!
 	QString tempFileName( "" );
+	// Only in case of error do we set result to false, don't forget!!
+	bool result = true;
+	KTempDir* tmpDir = 0;
+
 	if ( !url.isLocalFile() )
 	{
-		if ( ! KIO::NetAccess::download( url, tempFileName, widget() ) )
+		KIO::UDSEntry node;
+		KIO::NetAccess::stat( url, node, widget() );
+		if ( !node.isDir() )
 		{
-			slotShowError( i18n( "The URL <b>%1</b> cannot be downloaded." ).arg( url.prettyURL() ) );
-			tempFileName = "";
+			if ( ! KIO::NetAccess::download( url, tempFileName, widget() ) )
+			{
+				slotShowError( i18n( "<qt>The URL <b>%1</b> cannot be downloaded.</qt>", url.prettyUrl() ) );
+				tempFileName = ""; // Not sure if download has already touched this tempFileName when there is an error
+				result = false;
+			}
+		}
+		else
+		{
+			tmpDir = new KTempDir(KStandardDirs::locateLocal("tmp", "kompare"));
+			tmpDir->setAutoRemove( true ); // Yes this is the default but just to make sure
+			if ( ! KIO::NetAccess::dircopy( url, KUrl( tmpDir->name() ), widget() ) )
+			{
+				slotShowError( i18n( "<qt>The URL <b>%1</b> cannot be downloaded.</qt>", url.prettyUrl() ) );
+				delete tmpDir;
+				tmpDir = 0;
+				result = false;
+			}
+			else
+			{
+				tempFileName = tmpDir->name();
+				kDebug(8101) << "tempFileName = " << tempFileName << endl;
+				// If a directory is copied into KTempDir then the directory in 
+				// here is what I need to add to tempFileName
+				QDir dir( tempFileName );
+				QStringList entries = dir.entryList( QDir::Dirs | QDir::NoDotAndDotDot );
+				if ( entries.size() == 1 ) // More than 1 entry in here means big problems!!!
+				{
+					if ( !tempFileName.endsWith( '/' ) )
+						tempFileName += '/';
+					tempFileName += entries.at( 0 );
+					tempFileName += '/';
+				}
+				else
+				{
+					kDebug(8101) << "Yikes, nothing downloaded?" << endl;
+					delete tmpDir;
+					tmpDir = 0;
+					tempFileName = "";
+					result = false;
+				}
+			}
 		}
-		return tempFileName;
 	}
 	else
 	{
 		// is Local already, check if exists
 		if ( exists( url.path() ) )
-			return url.path();
+			tempFileName = url.path();
 		else
 		{
-			slotShowError( i18n( "The URL <b>%1</b> does not exist on your system." ).arg( url.prettyURL() ) );
-			return tempFileName;
+			slotShowError( i18n( "<qt>The URL <b>%1</b> does not exist on your system.</qt>", url.prettyUrl() ) );
+			result = false;
 		}
 	}
+
+	if ( addToSource )
+	{
+		m_info.localSource = tempFileName;
+		m_info.sourceKTempDir = tmpDir;
+	}
+	else
+	{
+		m_info.localDestination = tempFileName;
+		m_info.destinationKTempDir = tmpDir;
+	}
+
+	return result;
 }
 
 void KomparePart::cleanUpTemporaryFiles()
 {
-	// i hope a local file will not be removed if it was not downloaded...
+	kDebug(8101) << "Cleaning temporary files." << endl;
 	if ( !m_info.localSource.isEmpty() )
-		KIO::NetAccess::removeTempFile( m_info.localSource );
+	{
+		if ( m_info.sourceKTempDir == 0 )
+			KIO::NetAccess::removeTempFile( m_info.localSource );
+		else
+		{
+			delete m_info.sourceKTempDir;
+			m_info.sourceKTempDir = 0;
+		}
+		m_info.localSource = "";
+	}
 	if ( !m_info.localDestination.isEmpty() )
-		KIO::NetAccess::removeTempFile( m_info.localDestination );
+	{
+		if ( m_info.destinationKTempDir == 0  )
+			KIO::NetAccess::removeTempFile( m_info.localDestination );
+		else
+		{
+			delete m_info.destinationKTempDir;
+			m_info.destinationKTempDir = 0;
+		}
+		m_info.localDestination = "";
+	}
 }
 
-void KomparePart::compare( const KURL& source, const KURL& destination )
+void KomparePart::compare( const KUrl& source, const KUrl& destination )
 {
+	// FIXME: This is silly, i can use NetAccess::stat to figure out what it is and not
+	// wait until i am in the modellist to determine the mode we're supposed to be in.
+	// That should make the code more readable
+	// I should store the KTempDir(s)/File(s) in the Info struct as well and delete it at the right time
 	m_info.source = source;
 	m_info.destination = destination;
 
-	m_info.localSource = fetchURL( source );
-	m_info.localDestination = fetchURL( destination );
+	// FIXME: (Not urgent) But turn this into an enum, for now i cant find a nice name for the enum that has Source and Destination as values
+	// For now we do not do error checking, user has already been notified and if the localString is empty then we dont diff
+	fetchURL( source, true );
+	fetchURL( destination, false );
 
 	emit kompareInfo( &m_info );
 
 	if ( !m_info.localSource.isEmpty() && !m_info.localDestination.isEmpty() )
 	{
-		m_modelList->compare( m_info.localSource, m_info.localDestination );
-		updateActions();
+		m_modelList->compare();
 		updateCaption();
 		updateStatus();
 	}
+	updateActions();
 }
 
-void KomparePart::compareFiles( const KURL& sourceFile, const KURL& destinationFile )
+void KomparePart::compareFiles( const KUrl& sourceFile, const KUrl& destinationFile )
 {
-	emit kompareInfo( &m_info );
-
 	m_info.mode = Kompare::ComparingFiles;
 
 	m_info.source = sourceFile;
 	m_info.destination = destinationFile;
 
-	m_info.localSource = fetchURL( sourceFile );
-	m_info.localDestination = fetchURL( destinationFile );
+	// FIXME: (Not urgent) But turn this into an enum, for now i cant find a nice name for the enum that has Source and Destination as values
+	// For now we do not do error checking, user has already been notified and if the localString is empty then we dont diff
+	fetchURL( sourceFile, true );
+	fetchURL( destinationFile, false );
+
+	emit kompareInfo( &m_info );
 
 	if ( !m_info.localSource.isEmpty() && !m_info.localDestination.isEmpty() )
 	{
-		m_modelList->compareFiles( m_info.localSource, m_info.localDestination );
-		updateActions();
+		m_modelList->compareFiles();
 		updateCaption();
 		updateStatus();
 	}
+	updateActions();
 }
 
-void KomparePart::compareDirs( const KURL& sourceDirectory, const KURL& destinationDirectory )
+void KomparePart::compareDirs( const KUrl& sourceDirectory, const KUrl& destinationDirectory )
 {
-	emit kompareInfo( &m_info );
-
 	m_info.mode = Kompare::ComparingDirs;
 
 	m_info.source = sourceDirectory;
 	m_info.destination = destinationDirectory;
 
-	m_info.localSource = fetchURL( sourceDirectory );
-	m_info.localDestination = fetchURL( destinationDirectory );
+	fetchURL( sourceDirectory, true );
+	fetchURL( destinationDirectory, false );
+
+	emit kompareInfo( &m_info );
 
 	if ( !m_info.localSource.isEmpty() && !m_info.localDestination.isEmpty() )
 	{
-		m_modelList->compareDirs( m_info.localSource, m_info.localDestination );
-		updateActions();
+		m_modelList->compareDirs();
 		updateCaption();
 		updateStatus();
 	}
+	updateActions();
 }
 
-void KomparePart::compare3Files( const KURL& /*originalFile*/, const KURL& /*changedFile1*/, const KURL& /*changedFile2*/ )
+void KomparePart::compare3Files( const KUrl& /*originalFile*/, const KUrl& /*changedFile1*/, const KUrl& /*changedFile2*/ )
 {
 	// FIXME: actually implement this some day :)
 	updateActions();
@@ -362,40 +454,40 @@ void KomparePart::compare3Files( const KURL& /*originalFile*/, const KURL& /*cha
 	updateStatus();
 }
 
-void KomparePart::openFileAndDiff( const KURL& file, const KURL& diffFile )
+void KomparePart::openFileAndDiff( const KUrl& file, const KUrl& diffFile )
 {
-	emit kompareInfo( &m_info );
-
 	m_info.source = file;
 	m_info.destination = diffFile;
 
-	m_info.localSource = fetchURL( file );
-	m_info.localDestination = fetchURL( diffFile );
+	fetchURL( file, true );
+	fetchURL( diffFile, false );
 	m_info.mode = Kompare::BlendingFile;
 
+	emit kompareInfo( &m_info );
+
 	if ( !m_info.localSource.isEmpty() && !m_info.localDestination.isEmpty() )
 	{
-		m_modelList->openFileAndDiff( m_info.localSource, m_info.localDestination );
-		updateActions();
+		m_modelList->openFileAndDiff();
 		updateCaption();
 		updateStatus();
 	}
+	updateActions();
 }
 
-void KomparePart::openDirAndDiff ( const KURL& dir,  const KURL& diffFile )
+void KomparePart::openDirAndDiff ( const KUrl& dir,  const KUrl& diffFile )
 {
-	emit kompareInfo( &m_info );
-
 	m_info.source = dir;
 	m_info.destination = diffFile;
 
-	m_info.localSource = fetchURL( dir );
-	m_info.localDestination = fetchURL( diffFile );
+	fetchURL( dir, true );
+	fetchURL( diffFile, false );
 	m_info.mode = Kompare::BlendingDir;
 
+	emit kompareInfo( &m_info );
+
 	if ( !m_info.localSource.isEmpty() && !m_info.localDestination.isEmpty() )
 	{
-		m_modelList->openDirAndDiff( m_info.localSource, m_info.localDestination );
+		m_modelList->openDirAndDiff();
 		updateActions();
 		updateCaption();
 		updateStatus();
@@ -406,7 +498,7 @@ bool KomparePart::openFile()
 {
 	// This is called from openURL
 	// This is a little inefficient but i will do it anyway
-	openDiff( KURL( m_file ) );
+	openDiff( url() );
 	return true;
 }
 
@@ -421,29 +513,31 @@ bool KomparePart::saveAll()
 
 void KomparePart::saveDiff()
 {
-	KDialogBase* dlg = new KDialogBase( widget(), "save_options",
-	                                    true /* modal */, i18n("Diff Options"),
-	                                    KDialogBase::Ok|KDialogBase::Cancel );
+	KDialog dlg( widget() );
+	dlg.setName( "save_options" );
+	dlg.setModal( true );
+	dlg.setWindowTitle( i18n("Diff Options") );
+	dlg.setButtons( KDialog::Ok|KDialog::Cancel );
 	KompareSaveOptionsWidget* w = new KompareSaveOptionsWidget(
 	                                             m_info.localSource,
 	                                             m_info.localDestination,
-	                                             m_diffSettings, dlg );
-	dlg->setMainWidget( w );
-	dlg->setButtonOK( KStdGuiItem::save() );
+	                                             m_diffSettings, &dlg );
+	dlg.setMainWidget( w );
+	dlg.setButtonGuiItem( KDialog::Ok, KStandardGuiItem::save() );
 
-	if( dlg->exec() ) {
+	if( dlg.exec() ) {
 		w->saveOptions();
-		KConfig* config = instance()->config();
-		saveProperties( config );
+		KSharedConfig::Ptr config = componentData().config();
+		saveProperties( config.data() );
 		config->sync();
 
 		while ( 1 )
 		{
-			KURL url = KFileDialog::getSaveURL( m_info.destination.url(),
+			KUrl url = KFileDialog::getSaveUrl( m_info.destination.url(),
 			              i18n("*.diff *.dif *.patch|Patch Files"), widget(), i18n( "Save .diff" ) );
-			if ( KIO::NetAccess::exists( url, false, widget() ) )
+			if ( KIO::NetAccess::exists( url, KIO::NetAccess::DestinationSide, widget() ) )
 			{
-				int result = KMessageBox::warningYesNoCancel( widget(), i18n("The file exists or is write-protected; do you want to overwrite it?"), i18n("File Exists") );
+				int result = KMessageBox::warningYesNoCancel( widget(), i18n("The file exists or is write-protected; do you want to overwrite it?"), i18n("File Exists"), KGuiItem(i18n("Overwrite")), KGuiItem(i18n("Do Not Overwrite")) );
 				if ( result == KMessageBox::Cancel )
 				{
 					break;
@@ -454,9 +548,9 @@ void KomparePart::saveDiff()
 				}
 				else
 				{
-					kdDebug(8103) << "URL = " << url.prettyURL() << endl;
-					kdDebug(8103) << "Directory = " << w->directory() << endl;
-					kdDebug(8103) << "DiffSettings = " << m_diffSettings << endl;
+					kDebug(8103) << "URL = " << url.prettyUrl() << endl;
+					kDebug(8103) << "Directory = " << w->directory() << endl;
+					kDebug(8103) << "DiffSettings = " << m_diffSettings << endl;
 
 					m_modelList->saveDiff( url.url(), w->directory(), m_diffSettings );
 					break;
@@ -464,23 +558,22 @@ void KomparePart::saveDiff()
 			}
 			else
 			{
-				kdDebug(8103) << "URL = " << url.prettyURL() << endl;
-				kdDebug(8103) << "Directory = " << w->directory() << endl;
-				kdDebug(8103) << "DiffSettings = " << m_diffSettings << endl;
+				kDebug(8103) << "URL = " << url.prettyUrl() << endl;
+				kDebug(8103) << "Directory = " << w->directory() << endl;
+				kDebug(8103) << "DiffSettings = " << m_diffSettings << endl;
 
 				m_modelList->saveDiff( url.url(), w->directory(), m_diffSettings );
 				break;
 			}
 		}
 	}
-	delete dlg;
 }
 
-KAboutData *KomparePart::createAboutData()
+KAboutData* KomparePart::createAboutData()
 {
-    KAboutData *about = new KAboutData("kompare", I18N_NOOP("KomparePart"), "3.2");
-    about->addAuthor("John Firebaugh", "Author", "jfirebaugh@kde.org");
-    about->addAuthor("Otto Bruggeman", "Author", "otto.bruggeman@home.nl" );
+    KAboutData *about = new KAboutData("kompare", 0, ki18n("KomparePart"), "4.0");
+    about->addAuthor(ki18n("John Firebaugh"), ki18n("Author"), "jfirebaugh@kde.org");
+    about->addAuthor(ki18n("Otto Bruggeman"), ki18n("Author"), "bruggie@gmail.com" );
     return about;
 }
 
@@ -509,8 +602,8 @@ void KomparePart::slotSetStatus( enum Kompare::Status status )
 
 void KomparePart::updateCaption()
 {
-	QString source = m_info.source.prettyURL();
-	QString destination = m_info.destination.prettyURL();
+	QString source = m_info.source.prettyUrl();
+	QString destination = m_info.destination.prettyUrl();
 
 	QString text;
 
@@ -520,7 +613,7 @@ void KomparePart::updateCaption()
 	case Kompare::ComparingDirs :
 	case Kompare::BlendingFile :
 	case Kompare::BlendingDir :
-		text = source + ":" + destination;
+		text = source + " -- " + destination; // no need to translate this " -- "
 		break;
 	case Kompare::ShowingDiff :
 		text = source;
@@ -534,35 +627,35 @@ void KomparePart::updateCaption()
 
 void KomparePart::updateStatus()
 {
-	QString source = m_info.source.prettyURL();
-	QString destination = m_info.destination.prettyURL();
+	QString source = m_info.source.prettyUrl();
+	QString destination = m_info.destination.prettyUrl();
 
 	QString text;
 
 	switch ( m_info.mode )
 	{
 	case Kompare::ComparingFiles :
-		text = i18n( "Comparing file %1 with file %2" )
-		   .arg( source )
-		   .arg( destination );
+		text = i18n( "Comparing file %1 with file %2" ,
+		     source ,
+		     destination );
 		break;
 	case Kompare::ComparingDirs :
-		text = i18n( "Comparing files in %1 with files in %2" )
-		   .arg( source )
-		   .arg( destination );
+		text = i18n( "Comparing files in %1 with files in %2" ,
+		     source ,
+		     destination );
 		break;
 	case Kompare::ShowingDiff :
-		text = i18n( "Viewing diff output from %1" ).arg( source );
+		text = i18n( "Viewing diff output from %1", source );
 		break;
 	case Kompare::BlendingFile :
-		text = i18n( "Blending diff output from %1 into file %2" )
-		    .arg( source )
-		    .arg( destination );
+		text = i18n( "Blending diff output from %1 into file %2" ,
+		      source ,
+		      destination );
 		break;
 	case Kompare::BlendingDir :
-		text = i18n( "Blending diff output from %1 into folder %2" )
-		    .arg( m_info.source.prettyURL() )
-		    .arg( m_info.destination.prettyURL() );
+		text = i18n( "Blending diff output from %1 into folder %2" ,
+		      m_info.source.prettyUrl() ,
+		      m_info.destination.prettyUrl() );
 		break;
 	default:
 		break;
@@ -578,7 +671,7 @@ void KomparePart::slotShowError( QString error )
 
 void KomparePart::slotSwap()
 {
-	if ( isModified() )
+	if ( m_modelList->hasUnsavedChanges() )
 	{
 		int query = KMessageBox::warningYesNoCancel
 		            (
@@ -586,8 +679,8 @@ void KomparePart::slotSwap()
 		                i18n( "You have made changes to the destination file(s).\n"
 		                      "Would you like to save them?" ),
 		                i18n(  "Save Changes?" ),
-		                KStdGuiItem::save(),
-		                KStdGuiItem::discard()
+		                KStandardGuiItem::save(),
+		                KStandardGuiItem::discard()
 		            );
 
 		if ( query == KMessageBox::Yes )
@@ -598,13 +691,7 @@ void KomparePart::slotSwap()
 	}
 
 	// Swap the info in the Kompare::Info struct
-	KURL url = m_info.source;
-	m_info.source = m_info.destination;
-	m_info.destination = url;
-
-	QString string = m_info.localSource;
-	m_info.localSource = m_info.localDestination;
-	m_info.localDestination = string;
+	m_info.swapSourceWithDestination();
 
 	// Update window caption and statusbar text
 	updateCaption();
@@ -613,6 +700,34 @@ void KomparePart::slotSwap()
 	m_modelList->swap();
 }
 
+void KomparePart::slotRefreshDiff()
+{
+	if ( m_modelList->hasUnsavedChanges() )
+	{
+		int query = KMessageBox::warningYesNoCancel
+		            (
+		                widget(),
+		                i18n( "You have made changes to the destination file(s).\n"
+		                      "Would you like to save them?" ),
+		                i18n(  "Save Changes?" ),
+		                KStandardGuiItem::save(),
+		                KStandardGuiItem::discard()
+		            );
+
+		if ( query == KMessageBox::Cancel )
+			return; // Abort prematurely so no refreshing
+
+		if ( query == KMessageBox::Yes )
+			m_modelList->saveAll();
+	}
+
+	// For this to work properly you have to refetch the files from their (remote) locations
+	cleanUpTemporaryFiles();
+	fetchURL( m_info.source, true );
+	fetchURL( m_info.destination, false );
+	m_modelList->refresh();
+}
+
 void KomparePart::slotShowDiffstats( void )
 {
 	// Fetch all the args needed for komparestatsmessagebox
@@ -666,7 +781,7 @@ void KomparePart::slotShowDiffstats( void )
 		KMessageBox::information( 0L, i18n(
 		    "No diff file, or no 2 files have been diffed. "
 		    "Therefore no stats are available."),
-		    i18n("Diff Statistics"), QString::null, false );
+		    i18n("Diff Statistics"), QString(), false );
 	}
 	else if ( m_modelList->modelCount() == 1 ) { // 1 file in diff, or 2 files compared
 		KMessageBox::information( 0L, i18n(
@@ -677,12 +792,12 @@ void KomparePart::slotShowDiffstats( void )
 		    "\n"
 		    "Format: %3\n"
 		    "Number of hunks: %4\n"
-		    "Number of differences: %5")
-		    .arg(oldFile).arg(newFile).arg(diffFormat)
-		    .arg(noOfHunks).arg(noOfDiffs),
-		    i18n("Diff Statistics"), QString::null, false );
+		    "Number of differences: %5",
+		     oldFile, newFile, diffFormat,
+		     noOfHunks, noOfDiffs),
+		    i18n("Diff Statistics"), QString(), false );
 	} else { // more than 1 file in diff, or 2 directories compared
-		KMessageBox::information( 0L, i18n(
+		KMessageBox::information( 0L, ki18n(
 		    "Statistics:\n"
 		    "\n"
 		    "Number of files in diff file: %1\n"
@@ -693,15 +808,16 @@ void KomparePart::slotShowDiffstats( void )
 		    "\n"
 		    "Number of hunks: %5\n"
 		    "Number of differences: %6")
-		    .arg(filesInDiff).arg(diffFormat).arg(oldFile)
-		    .arg(newFile).arg(noOfHunks).arg(noOfDiffs),
-		    i18n("Diff Statistics"), QString::null, false );
+		    .subs(filesInDiff).subs(diffFormat).subs(oldFile)
+		    .subs(newFile).subs(noOfHunks).subs(noOfDiffs)
+                    .toString(),
+		    i18n("Diff Statistics"), QString(), false );
 	}
 }
 
 bool KomparePart::queryClose()
 {
-	if( !isModified() ) return true;
+	if ( !m_modelList->hasUnsavedChanges() ) return true;
 
 	int query = KMessageBox::warningYesNoCancel
 	            (
@@ -709,8 +825,8 @@ bool KomparePart::queryClose()
 	                i18n("You have made changes to the destination file(s).\n"
 	                     "Would you like to save them?" ),
 	                i18n( "Save Changes?" ),
-	                KStdGuiItem::save(),
-	                KStdGuiItem::discard()
+	                KStandardGuiItem::save(),
+	                KStandardGuiItem::discard()
 	            );
 
 	if( query == KMessageBox::Cancel )
@@ -740,20 +856,14 @@ int KomparePart::saveProperties( KConfig *config )
 void KomparePart::optionsPreferences()
 {
 	// show preferences
-	KomparePrefDlg* pref = new KomparePrefDlg( m_viewSettings, m_diffSettings );
+	KomparePrefDlg pref( m_viewSettings, m_diffSettings );
 
-	connect( pref, SIGNAL(applyClicked()), this, SIGNAL(configChanged()) );
+	connect( &pref, SIGNAL(configChanged()), this, SIGNAL(configChanged()) );
 
-	if ( pref->exec() )
+	if ( pref.exec() )
 		emit configChanged();
 }
 
-void KomparePart::slotSetModified( bool modified )
-{ 
-	kdDebug() << "KomparePart::slotSetModified( " << modified << " );" << endl;
-	setModified( modified );
-	updateActions();
-	updateCaption();
-}
-
 #include "kompare_part.moc"
+
+K_EXPORT_PLUGIN( KomparePartFactory )
