@@ -1,19 +1,18 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2004-2006                                               *
+ *   copyright (C) 2004-2008                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #ifndef CODEGENFACTORY_H
 #define CODEGENFACTORY_H
 
-#include "../umlnamespace.h"
-#include "../codeaccessormethod.h"
+#include "umlnamespace.h"
+#include "codeaccessormethod.h"
 
 // fwd decls
 class CodeGenerator;
@@ -21,6 +20,7 @@ class ClassifierCodeDocument;
 class CodeOperation;
 class CodeClassField;
 class CodeClassFieldDeclarationBlock;
+class CodeGenPolicyExt;
 class UMLClassifier;
 class UMLOperation;
 class UMLAttribute;
@@ -114,6 +114,14 @@ namespace CodeGenFactory {
      * Currently unused (for possible future use)
      */
     CodeDocument * newClassifierCodeDocument (UMLClassifier * classifier);
+
+    /**
+     * Returns the CodeGenPolicyExt for the given Uml::Programming_Language
+     *
+     * @param pl The Uml::Programming_Language for which we have to create the CodeGenPolicyExt
+     * @return A Language Specific CodeGenPolicyExt if the Language supports it else NULL
+     */
+    CodeGenPolicyExt* newCodeGenPolicyExt(Uml::Programming_Language pl);
 }
 
 #endif //CODEGENFACTORY_H
