@@ -12,7 +12,7 @@
 #ifndef SEQLINEWIDGET_H
 #define SEQLINEWIDGET_H
 
-#include <qcanvas.h>
+#include <q3canvas.h>
 
 class UMLView;
 class ObjectWidget;
@@ -22,7 +22,7 @@ class ObjectWidget;
  * @author Paul Hensgen
  * Bugs and comments to uml-devel@lists.sf.net or http://bugs.kde.org
  */
-class SeqLineWidget : public QCanvasLine {
+class SeqLineWidget : public Q3CanvasLine {
 public:
     /**
      * Constructor.
@@ -43,6 +43,15 @@ public:
      */
     int onWidget(const QPoint & p);
 
+    /**
+     * Return whether on the destruction box.
+     *
+     * @param p The point to investigate.
+     * @return  Non-zero if point is on the destruction box of this sequence line.
+     */
+    int onDestructionBox ( const QPoint & p );
+
+
     /**
      * Clean up anything before deletion.
      */
@@ -109,8 +118,8 @@ protected:
 
     /// The destruction box.
     struct DestructionBox {
-        QCanvasLine * line1;
-        QCanvasLine * line2;
+        Q3CanvasLine * line1;
+        Q3CanvasLine * line2;
         void setLine1Points(QRect rect) {
             line1->setPoints( rect.x(), rect.y(),
                               rect.x() + rect.width(), rect.y() + rect.height() );
